@@ -31,6 +31,22 @@
 #define Py_RETURN_NONE return Py_INCREF(Py_None), Py_None
 #endif
 
+#if PY_MAJOR_VERSION >= 3
+  #define MOD_ERROR_VAL NULL
+  #define MOD_SUCCESS_VAL(val) val
+  #define MOD_INIT(name) PyMODINIT_FUNC PyInit_##name(void)
+  #define MOD_DEF(ob, name, doc, methods) \
+              static struct PyModuleDef moduledef = { \
+                              PyModuleDef_HEAD_INIT, name, doc, -1, methods, }; \
+                  ob = PyModule_Create(&moduledef);
+#else
+  #define MOD_ERROR_VAL
+  #define MOD_SUCCESS_VAL(val)
+  #define MOD_INIT(name) void init##name(void)
+  #define MOD_DEF(ob, name, doc, methods) \
+              ob = Py_InitModule3(name, methods, doc);
+#endif
+
 static PyObject *PacparserError;
 // Initialize PAC parser.
 //
@@ -52,7 +68,7 @@ py_pacparser_init(PyObject *self, PyObject *args)
 
 // Parses the PAC script string.
 //
-// Evaulates the PAC script string in the JavaScript context created by
+// Evaluates the PAC script string in the JavaScript context created by
 // pacparser_init.
 static PyObject *                          // 0 (=Failure) or 1 (=Success)
 py_pacparser_parse_pac_string(PyObject *self, PyObject *args)
@@ -137,12 +153,14 @@ static PyMethodDef  PpMethods[] = {
   {NULL, NULL, 0, NULL}
 };
 
-PyMODINIT_FUNC
-init_pacparser(void)
+MOD_INIT(_pacparser)
 {
   PyObject *m;
-  m = Py_InitModule("_pacparser", PpMethods);
+  MOD_DEF(m, "_pacparser", NULL, PpMethods)
+  if(m == NULL)
+      return MOD_ERROR_VAL;
   PacparserError = PyErr_NewException("pacparser.error", NULL, NULL);
   Py_INCREF(PacparserError);
   PyModule_AddObject(m, "error", PacparserError);
+  return MOD_SUCCESS_VAL(m);
 }
